@@ -25,7 +25,10 @@ icons = [
 ]
 
 IGNORED_ALERTS = {
-	"Reizigersinformatie #MoveSafe"
+	"Mondmaskerplicht",
+	"Port du masque obligatoire",
+	"Face mask mandatory",
+	"Maskenpflicht"
 }
 
 
